@@ -8,12 +8,18 @@ from .signals import user_token_authenticated
 
 class JWTAuthentication(Base):
     def get_validated_token(self, raw_token):
+        print('shitt')
         return token_resolver.resolve_valid(
             raw_token, from_classes=api_settings.AUTH_TOKEN_CLASSES,
         )
 
     def authenticate(self, request):
-        user, token = super().authenticate(request)
+        result = super().authenticate(request)
+
+        if result is None:
+            return None
+
+        user, token = result
         user_token_authenticated.send(
             self.__class__, user=user, token=token, request=request
         )
