@@ -8,7 +8,10 @@ class TokenAdmin(admin.ModelAdmin):
     list_display = 'id', 'jti', 'parent_id', 'expired_at', 'created_at',
     date_hierarchy = 'created_at'
     autocomplete_fields = 'parent',
-    search_fields = 'id', 'jti', 'token',
+    search_fields = 'id', 'jti', 'token', 'user_connections__user__username'
+
+    def get_queryset(self, request):
+        return super().get_queryset(request).distinct()
 
 
 @admin.register(TokenUserConnection)
